@@ -22,7 +22,7 @@ class MMAMSInterface(CodeInterface, CommonCodeInterface, LiteratureReferencesMix
     post-collision effect.
     
     Relevant references:
-        .. [#] Gaburov E., Lombardi J. C. & Portegies Zwart S., 2008, MNRAS, 383, L5 [2008MNRAS.383L...5G]
+        .. [#] ADS:2008MNRAS.383L...5G (Gaburov E., Lombardi J. C. & Portegies Zwart S., 2008, MNRAS, 383, L5)
     """
     include_headers = ['worker_code.h']
     
